I8080Transfer

Struct I8080Transfer 

pub struct I8080Transfer<'d, BUF: DmaTxBuffer, Dm: DriverMode> { /* private fields */ }
Represents an ongoing (or potentially finished) transfer using the I8080 LCD interface

Implementations

Source

impl<'d, BUF: DmaTxBuffer, Dm: DriverMode> I8080Transfer<'d, BUF, Dm>

pub fn is_done(&self) -> bool

Returns whether Self::wait will not block.

pub fn cancel(self) -> (I8080<'d, Dm>, BUF::Final)

Stops this transfer on the spot and returns the peripheral and buffer.

pub fn wait(self) -> (Result<(), DmaError>, I8080<'d, Dm>, BUF::Final)

Waits for the transfer to finish and returns the peripheral and buffer.

Also clears the transfer interrupt so it can be used in interrupt handlers to handle the interrupt.

Source

impl<BUF: DmaTxBuffer> I8080Transfer<'_, BUF, Async>

pub async fn wait_for_done(&mut self)

Waits for Self::is_done to return true.